#**************************************************************************
#   Copyright (C) 2006 by Michael Andreen <harvATruinDOTnu>               *
#                                                                         *
#   This program is free software; you can redistribute it and/or modify  *
#   it under the terms of the GNU General Public License as published by  *
#   the Free Software Foundation; either version 2 of the License, or     *
#   (at your option) any later version.                                   *
#                                                                         *
#   This program is distributed in the hope that it will be useful,       *
#   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
#   GNU General Public License for more details.                          *
#                                                                         *
#   You should have received a copy of the GNU General Public License     *
#   along with this program; if not, write to the                         *
#   Free Software Foundation, Inc.,                                       *
#   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
#**************************************************************************/

package ND::Include;
use strict;
use warnings;
use CGI qw{:standard};
require Exporter;

our @ISA = qw/Exporter/;

our @EXPORT = qw/min max parseValue prettyValue pa_xp/;

sub min {
    my ($x,$y) = @_;
    return ($x > $y ? $y : $x);
}

sub max {
    my ($x,$y) = @_;
    return ($x < $y ? $y : $x);
}

sub parseValue {
	if (defined $_[0] && $_[0] =~ /^(-?\d+(?:\.\d+)?)([khMG])?$/){
		return $1 unless defined $2;
		return $1*100 if $2 eq 'h';
		return $1*1000 if $2 eq 'k';
		return $1*1000000 if $2 eq 'M';
		return $1*1000000000 if $2 eq 'G';
	}
	return $_[0];
}

sub prettyValue {
	my ($value,$decimals) = @_;
	return sprintf('%.3e',$value) if $value > 1000000000000000;
	my $unit = '';
	my @units = ('k','M','G','T');
	for (my $i = 0; $value >= 1000 && $i < 4;$i++){
		$value /= 1000;
		$unit = $units[$i];
	}
	unless (defined $decimals){
		$decimals = '.0';
		$decimals = '.1' if $value < 100 && $unit;
		$decimals = '.2' if $value < 10 && $unit;
	}

	return sprintf('%'.$decimals.'f%s', $value,$unit);
}

sub pa_xp {
	my ($roids,$ascore,$avalue,$tscore,$tvalue) = @_;
	my $bravery = (max(0,min(2,$tscore/$ascore)-0.2)) * (min(2,$tvalue/$avalue)-0.1);
	return int(max($roids * 10 * $bravery,0))

}

1;
